@@ -27,8 +27,13 @@ describe 'barbican::api' do
       {
         :bind_host                                     => '0.0.0.0',
         :bind_port                                     => '9311',
-        :rpc_backend                                   => 'rabbit',
-        :rabbit_host                                   => '<SERVICE_DEFAULT>',
+        :default_transport_url                         => '<SERVICE DEFAULT>',
+        :rpc_response_timeout                          => '<SERVICE DEFAULT>',
+        :control_exchange                              => '<SERVICE DEFAULT>',
+        :notification_transport_url                    => '<SERVICE DEFAULT>',
+        :notification_driver                           => '<SERVICE DEFAULT>',
+        :notification_topics                           => '<SERVICE DEFAULT>',
+        :rabbit_host                                   => '<SERVICE DEFAULT>',
         :rabbit_hosts                                  => ['<SERVICE DEFAULT>'],
         :rabbit_password                               => '<SERVICE DEFAULT>',
         :rabbit_port                                   => '<SERVICE DEFAULT>',
@@ -51,6 +56,7 @@ describe 'barbican::api' do
         :kombu_ssl_keyfile                             => '<SERVICE DEFAULT>',
         :kombu_ssl_version                             => '<SERVICE DEFAULT>',
         :kombu_reconnect_delay                         => '<SERVICE DEFAULT>',
+        :kombu_failover_strategy                       => '<SERVICE DEFAULT>',
         :manage_service                                => true,
         :enabled                                       => true,
         :enabled_secretstore_plugins                   => ['<SERVICE DEFAULT>'],
@@ -61,13 +67,21 @@ describe 'barbican::api' do
         :retry_scheduler_initial_delay_seconds         => '<SERVICE DEFAULT>',
         :retry_scheduler_periodic_interval_max_seconds => '<SERVICE DEFAULT>',
         :service_name                                  => platform_params[:service_name],
+        :enable_proxy_headers_parsing                  => '<SERVICE DEFAULT>',
+        :multiple_secret_stores_enabled                => false,
+        :enabled_secret_stores                         => 'simple_crypto',
       }
     end
 
     [{
         :bind_host                                     => '127.0.0.1',
         :bind_port                                     => '9312',
-        :rpc_backend                                   => 'rabbit',
+        :default_transport_url                         => 'rabbit://bugs:bugs_bunny@localhost:1234/rabbithost',
+        :rpc_response_timeout                          => '120',
+        :control_exchange                              => 'barbican',
+        :notification_transport_url                    => 'rabbit://bugs:bugs_bunny@localhost:1234/rabbithost',
+        :notification_driver                           => 'kombu',
+        :notification_topics                           => 'notifications',
         :rabbit_host                                   => 'rabbithost',
         :rabbit_hosts                                  => ['rabbithost:1234'],
         :rabbit_password                               => 'bugs_bunny',
@@ -91,6 +105,7 @@ describe 'barbican::api' do
         :kombu_ssl_keyfile                             => 'path_to_keyfile',
         :kombu_ssl_version                             => '1.2',
         :kombu_reconnect_delay                         => '10',
+        :kombu_failover_strategy                       => 'shuffle',
         :enabled_secretstore_plugins                   => ['dogtag_crypto', 'store_crypto', 'kmip'],
         :enabled_crypto_plugins                        => ['simple_crypto'],
         :enabled_certificate_plugins                   => ['simple_certificate', 'dogtag'],
@@ -99,6 +114,9 @@ describe 'barbican::api' do
         :retry_scheduler_periodic_interval_max_seconds => 20.0,
         :max_allowed_secret_in_bytes                   => 20000,
         :max_allowed_request_size_in_bytes             => 2000000,
+        :enable_proxy_headers_parsing                  => false,
+        :multiple_secret_stores_enabled                => true,
+        :enabled_secret_stores                         => 'simple_crypto,dogtag,kmip',
       }
     ].each do |param_set|
       describe "when #{param_set == {} ? "using default" : "specifying"} class parameters" do
@@ -119,8 +137,10 @@ describe 'barbican::api' do
           "http://${::fqdn}:$param_hash[:bind_port]"
         end
 
-        it { is_expected.to contain_class 'barbican::api::logging' }
-        it { is_expected.to contain_class 'barbican::db' }
+        it { is_expected.to contain_class('barbican::deps') }
+        it { is_expected.to contain_class('barbican::api::logging') }
+        it { is_expected.to contain_class('barbican::db') }
+        it { is_expected.to contain_class('barbican::policy') }
 
         it { is_expected.to contain_package('barbican-api').with(
             :tag => ['openstack', 'barbican-package'],
@@ -146,21 +166,30 @@ describe 'barbican::api' do
         end
 
         it 'configures rabbit' do
-          is_expected.to contain_barbican_config('DEFAULT/rpc_backend').with_value(param_hash[:rpc_backend])
+          is_expected.to contain_barbican_config('DEFAULT/transport_url').with_value(param_hash[:default_transport_url])
+          is_expected.to contain_barbican_config('DEFAULT/rpc_response_timeout').with_value(param_hash[:rpc_response_timeout])
+          is_expected.to contain_barbican_config('DEFAULT/control_exchange').with_value(param_hash[:control_exchange])
+          is_expected.to contain_barbican_config('oslo_messaging_notifications/transport_url').with_value(param_hash[:notification_transport_url])
+          is_expected.to contain_barbican_config('oslo_messaging_notifications/driver').with_value(param_hash[:notification_driver])
+          is_expected.to contain_barbican_config('oslo_messaging_notifications/topics').with_value(param_hash[:notification_topics])
           is_expected.to contain_barbican_config('oslo_messaging_rabbit/rabbit_hosts').with_value(param_hash[:rabbit_hosts])
           is_expected.to contain_barbican_config('oslo_messaging_rabbit/rabbit_password').with_value(param_hash[:rabbit_password]).with_secret(true)
           is_expected.to contain_barbican_config('oslo_messaging_rabbit/rabbit_userid').with_value(param_hash[:rabbit_userid])
           is_expected.to contain_barbican_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value(param_hash[:rabbit_virtual_host])
           is_expected.to contain_barbican_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value(param_hash[:rabbit_heartbeat_timeout_threshold])
           is_expected.to contain_barbican_config('oslo_messaging_rabbit/heartbeat_rate').with_value(param_hash[:rabbit_heartbeat_rate])
+          is_expected.to contain_oslo__messaging__rabbit('barbican_config').with(
+            :rabbit_use_ssl     => true,
+            :kombu_ssl_ca_certs => 'path_to_certs',
+            :kombu_ssl_certfile => 'path_to_certfile',
+            :kombu_ssl_keyfile  => 'path_to_keyfile',
+            :kombu_ssl_version  => '1.2',
+          )
         end
 
-        it 'configures kombu certs' do
-          is_expected.to contain_barbican_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value(param_hash[:kombu_ssl_ca_certs])
-          is_expected.to contain_barbican_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value(param_hash[:kombu_ssl_certfile])
-          is_expected.to contain_barbican_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value(param_hash[:kombu_ssl_keyfile])
-          is_expected.to contain_barbican_config('oslo_messaging_rabbit/kombu_ssl_version').with_value(param_hash[:kombu_ssl_version])
+        it 'configures kombu params' do
           is_expected.to contain_barbican_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value(param_hash[:kombu_reconnect_delay])
+          is_expected.to contain_barbican_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value(param_hash[:kombu_failover_strategy])
         end
 
         it 'configures enabled plugins' do
@@ -173,9 +202,29 @@ describe 'barbican::api' do
           is_expected.to contain_barbican_config('certificate_event/enabled_certificate_event_plugins') \
             .with_value(param_hash[:enabled_certificate_event_plugins])
         end
+
+        it 'configures plugins in multiple plugin config' do
+          is_expected.to contain_barbican_config('secretstore/stores_lookup_suffix') \
+            .with_value(param_hash[:enabled_secret_stores])
+          is_expected.to contain_barbican_config('secretstore/enable_multiple_secret_stores') \
+            .with_value(param_hash[:multiple_secret_stores_enabled])
+        end
       end
     end
 
+    describe 'with enable_proxy_headers_parsing' do
+      let :pre_condition do
+          'class { "barbican::keystone::authtoken": password => "secret", }
+           include ::apache'
+      end
+
+      let :params do
+        default_params.merge!({:enable_proxy_headers_parsing => true })
+      end
+
+      it { is_expected.to contain_barbican_config('oslo_middleware/enable_proxy_headers_parsing').with_value(true) }
+    end
+
     describe 'with SSL socket options set' do
       let :pre_condition do
           'class { "barbican::keystone::authtoken": password => "secret", }
@@ -308,7 +357,7 @@ describe 'barbican::api' do
       case facts[:osfamily]
       when 'RedHat'
         let (:platform_params) do
-          { :service_name => 'barbican-api' } 
+          { :service_name => 'barbican-api' }
         end
         it_behaves_like 'barbican api redhat'
       when 'Debian'
