@@ -25,12 +25,16 @@ describe 'barbican::db' do
 
     context 'with default parameters' do
 
-      it { is_expected.to contain_barbican_config('database/connection').with_value('sqlite:////var/lib/barbican/barbican.sqlite') }
-      it { is_expected.to contain_barbican_config('database/idle_timeout').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_barbican_config('database/min_pool_size').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_barbican_config('database/max_retries').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_barbican_config('database/retry_interval').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_barbican_config('database/db_max_retries').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_oslo__db('barbican_config').with(
+        :db_max_retries => '<SERVICE DEFAULT>',
+        :connection     => 'sqlite:////var/lib/barbican/barbican.sqlite',
+        :idle_timeout   => '<SERVICE DEFAULT>',
+        :min_pool_size  => '<SERVICE DEFAULT>',
+        :max_pool_size  => '<SERVICE DEFAULT>',
+        :max_retries    => '<SERVICE DEFAULT>',
+        :retry_interval => '<SERVICE DEFAULT>',
+        :max_overflow   => '<SERVICE DEFAULT>',
+      )}
 
       # TODO(aschultz): remove once oslo is properly used
       it { is_expected.to contain_barbican_config('DEFAULT/sql_connection').with_value('sqlite:////var/lib/barbican/barbican.sqlite') }
@@ -45,6 +49,7 @@ describe 'barbican::db' do
         { :database_connection     => 'mysql+pymysql://barbican:barbican@localhost/barbican',
           :database_idle_timeout   => '3601',
           :database_min_pool_size  => '2',
+          :database_max_pool_size  => '11',
           :database_max_retries    => '11',
           :database_retry_interval => '11',
           :database_max_overflow   => '11',
@@ -53,13 +58,16 @@ describe 'barbican::db' do
         }
       end
 
-      it { is_expected.to contain_barbican_config('database/connection').with_value('mysql+pymysql://barbican:barbican@localhost/barbican').with_secret(true) }
-      it { is_expected.to contain_barbican_config('database/idle_timeout').with_value('3601') }
-      it { is_expected.to contain_barbican_config('database/min_pool_size').with_value('2') }
-      it { is_expected.to contain_barbican_config('database/max_retries').with_value('11') }
-      it { is_expected.to contain_barbican_config('database/retry_interval').with_value('11') }
-      it { is_expected.to contain_barbican_config('database/max_overflow').with_value('11') }
-      it { is_expected.to contain_barbican_config('database/db_max_retries').with_value('-1') }
+      it { is_expected.to contain_oslo__db('barbican_config').with(
+        :db_max_retries => '-1',
+        :connection     => 'mysql+pymysql://barbican:barbican@localhost/barbican',
+        :idle_timeout   => '3601',
+        :min_pool_size  => '2',
+        :max_pool_size  => '11',
+        :max_retries    => '11',
+        :retry_interval => '11',
+        :max_overflow   => '11',
+      )}
 
       # TODO(aschultz) remove once oslo is properly used
       it { is_expected.to contain_barbican_config('DEFAULT/sql_connection').with_value('mysql+pymysql://barbican:barbican@localhost/barbican').with_secret(true) }
@@ -70,7 +78,7 @@ describe 'barbican::db' do
 
     context 'with postgresql backend' do
       let :params do
-        { :database_connection     => 'postgresql://barbican:barbican@localhost/barbican', }
+        { :database_connection => 'postgresql://barbican:barbican@localhost/barbican', }
       end
 
       it 'install the proper backend package' do
@@ -80,7 +88,7 @@ describe 'barbican::db' do
 
     context 'with MySQL-python library as backend package' do
       let :params do
-        { :database_connection     => 'mysql://barbican:barbican@localhost/barbican', }
+        { :database_connection => 'mysql://barbican:barbican@localhost/barbican', }
       end
 
       it { is_expected.to contain_package('python-mysqldb').with(:ensure => 'present') }
@@ -88,7 +96,7 @@ describe 'barbican::db' do
 
     context 'with incorrect database_connection string' do
       let :params do
-        { :database_connection     => 'redis://barbican:barbican@localhost/barbican', }
+        { :database_connection => 'redis://barbican:barbican@localhost/barbican', }
       end
 
       it_raises 'a Puppet::Error', /validate_re/
@@ -96,7 +104,7 @@ describe 'barbican::db' do
 
     context 'with incorrect pymysql database_connection string' do
       let :params do
-        { :database_connection     => 'foo+pymysql://barbican:barbican@localhost/barbican', }
+        { :database_connection => 'foo+pymysql://barbican:barbican@localhost/barbican', }
       end
 
       it_raises 'a Puppet::Error', /validate_re/
@@ -105,8 +113,9 @@ describe 'barbican::db' do
 
   context 'on Debian platforms' do
     let :facts do
-      @default_facts.merge({ :osfamily => 'Debian',
-        :operatingsystem => 'Debian',
+      @default_facts.merge({ 
+        :osfamily               => 'Debian',
+        :operatingsystem        => 'Debian',
         :operatingsystemrelease => 'jessie',
       })
     end
@@ -115,11 +124,11 @@ describe 'barbican::db' do
 
     context 'with sqlite backend' do
       let :params do
-        { :database_connection     => 'sqlite:///var/lib/barbican/barbican.sqlite', }
+        { :database_connection => 'sqlite:///var/lib/barbican/barbican.sqlite', }
       end
 
       it 'install the proper backend package' do
-        is_expected.to contain_package('db_backend_package').with(
+        is_expected.to contain_package('python-pysqlite2').with(
           :ensure => 'present',
           :name   => 'python-pysqlite2',
           :tag    => 'openstack'
@@ -130,11 +139,11 @@ describe 'barbican::db' do
 
     context 'using pymysql driver' do
       let :params do
-        { :database_connection     => 'mysql+pymysql://barbican:barbican@localhost/barbican', }
+        { :database_connection => 'mysql+pymysql://barbican:barbican@localhost/barbican', }
       end
 
       it 'install the proper backend package' do
-        is_expected.to contain_package('db_backend_package').with(
+        is_expected.to contain_package('python-pymysql').with(
           :ensure => 'present',
           :name   => 'python-pymysql',
           :tag    => 'openstack'
@@ -147,10 +156,8 @@ describe 'barbican::db' do
   shared_examples_for 'barbican db on redhat' do
     context 'using pymysql driver' do
       let :params do
-        { :database_connection     => 'mysql+pymysql://barbican:barbican@localhost/barbican', }
+        { :database_connection => 'mysql+pymysql://barbican:barbican@localhost/barbican', }
       end
-
-      it { is_expected.not_to contain_package('db_backend_package') }
     end
   end
 
