@@ -34,8 +34,8 @@ describe 'barbican::keystone::authtoken' do
         is_expected.to contain_barbican_config('keystone_authtoken/password').with_value('barbican_password')
         is_expected.to contain_barbican_config('keystone_authtoken/auth_url').with_value('http://localhost:35357')
         is_expected.to contain_barbican_config('keystone_authtoken/project_name').with_value('services')
-        is_expected.to contain_barbican_config('keystone_authtoken/user_domain_name').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_barbican_config('keystone_authtoken/project_domain_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_barbican_config('keystone_authtoken/user_domain_name').with_value('Default')
+        is_expected.to contain_barbican_config('keystone_authtoken/project_domain_name').with_value('Default')
         is_expected.to contain_barbican_config('keystone_authtoken/insecure').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_barbican_config('keystone_authtoken/auth_section').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_barbican_config('keystone_authtoken/auth_type').with_value('password')
@@ -62,8 +62,6 @@ describe 'barbican::keystone::authtoken' do
         is_expected.to contain_barbican_config('keystone_authtoken/memcache_use_advanced_pool').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_barbican_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_barbican_config('keystone_authtoken/region_name').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_barbican_config('keystone_authtoken/revocation_cache_time').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_barbican_config('keystone_authtoken/signing_dir').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_barbican_config('keystone_authtoken/token_cache_time').with_value('<SERVICE DEFAULT>')
       end
     end
@@ -104,8 +102,6 @@ describe 'barbican::keystone::authtoken' do
           :memcached_servers                    => ['memcached01:11211','memcached02:11211'],
           :manage_memcache_package              => true,
           :region_name                          => 'region2',
-          :revocation_cache_time                => '11',
-          :signing_dir                          => '/var/cache',
           :token_cache_time                     => '301',
         })
       end
@@ -143,8 +139,6 @@ describe 'barbican::keystone::authtoken' do
         is_expected.to contain_barbican_config('keystone_authtoken/memcache_use_advanced_pool').with_value(params[:memcache_use_advanced_pool])
         is_expected.to contain_barbican_config('keystone_authtoken/memcached_servers').with_value('memcached01:11211,memcached02:11211')
         is_expected.to contain_barbican_config('keystone_authtoken/region_name').with_value(params[:region_name])
-        is_expected.to contain_barbican_config('keystone_authtoken/revocation_cache_time').with_value(params[:revocation_cache_time])
-        is_expected.to contain_barbican_config('keystone_authtoken/signing_dir').with_value(params[:signing_dir])
         is_expected.to contain_barbican_config('keystone_authtoken/token_cache_time').with_value(params[:token_cache_time])
       end
 
